@@ -27,4 +27,35 @@ public class StringUtils {
 		return (str == null) || (str.isEmpty());
 	}
 
+	/**
+	 * @param aName
+	 * @param bName
+	 * @return
+	 */
+	public static boolean equals(String a, String b) {
+		if(a == null) {
+			if(b == null) {
+				return true;
+			}
+		}
+		
+		if(b == null) {
+			return false; //aName was already checked for null.
+		}
+
+		return a.equals(b);
+	}
+
+	/**
+	 * @param text
+	 * @return
+	 */
+	public static String defaultString(String text) {
+		if (text == null) {
+			return "";
+		} else {
+			return text;
+		}
+	}
+
 }
