@@ -20,7 +20,7 @@
 
 package org.glom.web.client.ui.list;
 
-import java.util.ArrayList;
+import java.util.List;
 
 import org.glom.web.client.Utils;
 import org.glom.web.client.ui.cell.BooleanCell;
@@ -28,13 +28,14 @@ import org.glom.web.client.ui.cell.NavigationButtonCell;
 import org.glom.web.client.ui.cell.NumericCell;
 import org.glom.web.client.ui.cell.TextCell;
 import org.glom.web.shared.DataItem;
-import org.glom.web.shared.GlomNumericFormat;
-import org.glom.web.shared.layout.Formatting;
-import org.glom.web.shared.layout.LayoutGroup;
-import org.glom.web.shared.layout.LayoutItem;
-import org.glom.web.shared.layout.LayoutItemField;
-import org.glom.web.shared.layout.LayoutItemField.GlomFieldType;
+import org.glom.web.shared.libglom.Field.GlomFieldType;
+import org.glom.web.shared.libglom.NumericFormat;
+import org.glom.web.shared.libglom.layout.Formatting;
+import org.glom.web.shared.libglom.layout.LayoutGroup;
+import org.glom.web.shared.libglom.layout.LayoutItem;
+import org.glom.web.shared.libglom.layout.LayoutItemField;
 
+import com.google.gwt.core.client.GWT;
 import com.google.gwt.dom.client.Document;
 import com.google.gwt.dom.client.Element;
 import com.google.gwt.dom.client.Style.Unit;
@@ -61,7 +62,7 @@ import com.google.gwt.view.client.AbstractDataProvider;
 import com.google.gwt.view.client.ProvidesKey;
 
 /**
- * 
+ *
  */
 public abstract class ListTable extends Composite {
 
@@ -115,24 +116,41 @@ public abstract class ListTable extends Composite {
 		this.documentID = documentID;
 	}
 
-	protected void createCellTable(final LayoutGroup layoutGroup, final int numVisibleRows,
+	protected void createCellTable(final LayoutGroup layoutGroup, final String tableName, final int numVisibleRows,
 			final String navigationButtonLabel, final NavigationButtonCell navigationButtonCell) {
-		tableName = layoutGroup.getTableName(); // TODO: Is this in the regular libglom API, or is it a gwt-glom hack?
-												// murrayc
-		final ArrayList<LayoutItem> layoutItems = layoutGroup.getItems();
+		this.tableName = tableName;
+		final List<LayoutItem> layoutItems = layoutGroup.getItems();
 
+		ProvidesKey<DataItem[]> keyProvider = null;
 		final int primaryKeyIndex = layoutGroup.getPrimaryKeyIndex();
-		final LayoutItemField primaryKeyLayoutItem = (LayoutItemField) layoutItems.get(primaryKeyIndex);
-		final GlomFieldType primaryKeyFieldType = primaryKeyLayoutItem.getType();
-		final ProvidesKey<DataItem[]> keyProvider = new ProvidesKey<DataItem[]>() {
-			@Override
-			public Object getKey(final DataItem[] row) {
-				if (row.length == 1 && row[0] == null)
-					// an empty row
-					return null;
-				return Utils.getTypedDataItem(primaryKeyFieldType, row[primaryKeyIndex]);
+		if ((primaryKeyIndex < 0) || (primaryKeyIndex >= layoutItems.size())) {
+			GWT.log("createCellTable(): primaryKeyIndex is out of range: " + primaryKeyIndex);
+		} else {
+			final LayoutItem primaryKeyItem = layoutItems.get(primaryKeyIndex);
+			if (!(primaryKeyItem instanceof LayoutItemField)) {
+				GWT.log("createCellTable(): primaryKeyItem is not a LayoutItemField.");
+			} else {
+				final LayoutItemField primaryKeyLayoutItem = (LayoutItemField) primaryKeyItem;
+				final GlomFieldType primaryKeyFieldType = primaryKeyLayoutItem.getGlomType();
+
+				keyProvider = new ProvidesKey<DataItem[]>() {
+					@Override
+					public Object getKey(final DataItem[] row) {
+						if (row.length == 1 && row[0] == null) {
+							// an empty row
+							return null;
+						}
+
+						if ((primaryKeyIndex < 0) || (primaryKeyIndex >= row.length)) {
+							GWT.log("createCellTable() keyProvider.getKey(): primaryKeyIndex is out of range: " + primaryKeyIndex + ", row.length=" + row.length);
+							return null;
+						}
+
+						return Utils.getTypedDataItem(primaryKeyFieldType, row[primaryKeyIndex]);
+					}
+				};
 			}
-		};
+		}
 
 		// create the CellTable with the requested number of rows and the key provider
 		cellTable = new CellTable<DataItem[]>(numVisibleRows, keyProvider);
@@ -150,6 +168,8 @@ public abstract class ListTable extends Composite {
 			// only add columns for LayoutItemField types
 			if (layoutItem instanceof LayoutItemField) {
 				addColumn((LayoutItemField) layoutItem);
+			} else {
+				GWT.log("createCellTable(): Ignoring non-LayoutItemField layout item.");
 			}
 
 		}
@@ -234,7 +254,12 @@ public abstract class ListTable extends Composite {
 	private void addColumn(final LayoutItemField layoutItemField) {
 		// Setup the default alignment of the column.
 		HorizontalAlignmentConstant columnAlignment;
-		final Formatting formatting = layoutItemField.getFormatting();
+		Formatting formatting = layoutItemField.getFormatting();
+		if (formatting == null) {
+			GWT.log("addColumn(): Formatting is null for field=" + layoutItemField.getLayoutDisplayName());
+			formatting = new Formatting(); // Just to avoid null dereferencing later.
+		}
+
 		switch (formatting.getHorizontalAlignment()) {
 		case HORIZONTAL_ALIGNMENT_LEFT:
 			columnAlignment = HasHorizontalAlignment.ALIGN_LEFT;
@@ -251,16 +276,23 @@ public abstract class ListTable extends Composite {
 		// create a new column
 		Column<DataItem[], ?> column = null;
 		final int j = cellTable.getColumnCount();
-		switch (layoutItemField.getType()) {
+		switch (layoutItemField.getGlomType()) {
 
 		case TYPE_BOOLEAN:
 			column = new Column<DataItem[], Boolean>(new BooleanCell()) {
 				@Override
 				public Boolean getValue(final DataItem[] row) {
-					if (row.length == 1 && row[0] == null)
+					if (row.length == 1 && row[0] == null) {
 						// an empty row
 						return null;
-					return row[j].getBoolean();
+					}
+
+					if (j >= row.length) {
+						GWT.log("addColumn(): j=" + j + " is out of range. length=" + row.length);
+						return null;
+					} else {
+						return row[j].getBoolean();
+					}
 				}
 			};
 			// override the configured horizontal alignment
@@ -269,19 +301,27 @@ public abstract class ListTable extends Composite {
 
 		case TYPE_NUMERIC:
 			// create a GWT NumberFormat for the column
-			final GlomNumericFormat glomNumericFormat = formatting.getGlomNumericFormat();
-			final NumberFormat gwtNumberFormat = Utils.getNumberFormat(glomNumericFormat);
+			final NumericFormat numericFormat = formatting.getNumericFormat();
+			final NumberFormat gwtNumberFormat = Utils.getNumberFormat(numericFormat);
 
 			// create the actual column
-			column = new Column<DataItem[], Double>(new NumericCell(formatting.getTextFormatColourForeground(),
-					formatting.getTextFormatColourBackground(), gwtNumberFormat,
-					glomNumericFormat.getUseAltForegroundColourForNegatives(), glomNumericFormat.getCurrencyCode())) {
+			column = new Column<DataItem[], Double>(new NumericCell(
+					formatting.getTextFormatColorForegroundAsHTMLColor(),
+					formatting.getTextFormatColorBackgroundAsHTMLColor(), gwtNumberFormat,
+					numericFormat.getUseAltForegroundColorForNegatives(), numericFormat.getCurrencySymbol())) {
 				@Override
 				public Double getValue(final DataItem[] row) {
-					if (row.length == 1 && row[0] == null)
+					if (row.length == 1 && row[0] == null) {
 						// an empty row
 						return null;
-					return row[j].getNumber();
+					}
+
+					if (j >= row.length) {
+						GWT.log("addColumn(): j=" + j + " is out of range. length=" + row.length);
+						return null;
+					} else {
+						return row[j].getNumber();
+					}
 				}
 			};
 			break;
@@ -294,14 +334,21 @@ public abstract class ListTable extends Composite {
 		case TYPE_INVALID:
 		case TYPE_TIME:
 		case TYPE_TEXT:
-			column = new Column<DataItem[], String>(new TextCell(formatting.getTextFormatColourForeground(),
-					formatting.getTextFormatColourBackground())) {
+			column = new Column<DataItem[], String>(new TextCell(formatting.getTextFormatColorForegroundAsHTMLColor(),
+					formatting.getTextFormatColorBackgroundAsHTMLColor())) {
 				@Override
 				public String getValue(final DataItem[] row) {
-					if (row.length == 1 && row[0] == null)
+					if (row.length == 1 && row[0] == null) {
 						// an empty row
 						return null;
-					return row[j].getText();
+					}
+
+					if (j >= row.length) {
+						GWT.log("addColumn(): j=" + j + " is out of range. length=" + row.length);
+						return null;
+					} else {
+						return row[j].getText();
+					}
 				}
 			};
 			break;
