@@ -20,7 +20,6 @@
 package org.glom.web.server;
 
 import java.io.File;
-import java.io.FilenameFilter;
 import java.io.InputStream;
 import java.sql.Connection;
 import java.sql.SQLException;
@@ -33,12 +32,9 @@ import javax.servlet.ServletException;
 
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.io.FilenameUtils;
-import org.apache.commons.lang.StringUtils;
-import org.glom.libglom.BakeryDocument.LoadFailureCodes;
-import org.glom.libglom.Document;
-import org.glom.libglom.Glom;
-import org.glom.libglom.Report;
+import org.apache.commons.lang3.StringUtils;
 import org.glom.web.client.OnlineGlomService;
+import org.glom.web.server.libglom.Document;
 import org.glom.web.shared.DataItem;
 import org.glom.web.shared.DetailsLayoutAndData;
 import org.glom.web.shared.DocumentInfo;
@@ -46,7 +42,9 @@ import org.glom.web.shared.Documents;
 import org.glom.web.shared.NavigationRecord;
 import org.glom.web.shared.Reports;
 import org.glom.web.shared.TypedDataItem;
-import org.glom.web.shared.layout.LayoutGroup;
+import org.glom.web.shared.libglom.Report;
+import org.glom.web.shared.libglom.layout.LayoutGroup;
+import org.glom.web.shared.libglom.layout.LayoutItemPortal;
 
 import com.google.gwt.user.server.rpc.RemoteServiceServlet;
 import com.mchange.v2.c3p0.DataSources;
@@ -67,7 +65,8 @@ public class OnlineGlomServiceImpl extends RemoteServiceServlet implements Onlin
 	private static final String GLOM_FILE_EXTENSION = "glom";
 
 	// convenience class for dealing with the Online Glom configuration file
-	private class OnlineGlomProperties extends Properties {
+	// TODO: Turn this into a class with specific getters, and test it.
+	private static class OnlineGlomProperties extends Properties {
 		public String getKey(final String value) {
 			for (final String key : stringPropertyNames()) {
 				if (getProperty(key).trim().equals(value))
@@ -135,39 +134,16 @@ public class OnlineGlomServiceImpl extends RemoteServiceServlet implements Onlin
 				throw new Exception(errorMessage);
 			}
 
-			// Check to see if the native library of java libglom is visible to the JVM
-			if (!isNativeLibraryVisibleToJVM()) {
-				final String errorMessage = "The java-libglom shared library is not visible to the JVM."
-						+ " Ensure that 'java.library.path' is set with the path to the java-libglom shared library."
-						+ "\n: java.library.path: " + System.getProperty("java.library.path");
-				Log.error(errorMessage);
-				throw new Exception(errorMessage);
-			}
-
 			// Check for a specified default locale,
 			// for table titles, field titles, etc:
 			final String globalLocaleID = StringUtils.defaultString(config.getProperty("glom.document.locale"));
 
-			// This initialisation method can throw an UnsatisfiedLinkError if the java-libglom native library isn't
-			// available. But since we're checking for the error condition above, the UnsatisfiedLinkError will never be
-			// thrown.
-			Glom.libglom_init();
-
-			// Allow a fake connection, so sqlbuilder_get_full_query() can work:
-			Glom.set_fake_connection();
-
 			for (final File glomFile : glomFiles) {
 				final Document document = new Document();
-				document.set_file_uri("file://" + glomFile.getAbsolutePath());
-				final int error = 0;
-				final boolean retval = document.load(error);
+				document.setFileURI("file://" + glomFile.getAbsolutePath());
+				final boolean retval = document.load();
 				if (retval == false) {
-					String message;
-					if (LoadFailureCodes.LOAD_FAILURE_CODE_NOT_FOUND == LoadFailureCodes.swigToEnum(error)) {
-						message = "Could not find file: " + glomFile.getAbsolutePath();
-					} else {
-						message = "An unknown error occurred when trying to load file: " + glomFile.getAbsolutePath();
-					}
+					final String message = "An error occurred when trying to load file: " + glomFile.getAbsolutePath();
 					Log.error(message);
 					// continue with for loop because there may be other documents in the directory
 					continue;
@@ -214,38 +190,6 @@ public class OnlineGlomServiceImpl extends RemoteServiceServlet implements Onlin
 
 	}
 
-	/**
-	 * Checks if the java-libglom native library is visible to the JVM.
-	 * 
-	 * @return true if the java-libglom native library is visible to the JVM, false if it's not
-	 */
-	private boolean isNativeLibraryVisibleToJVM() {
-		final String javaLibraryPath = System.getProperty("java.library.path");
-
-		// Go through all the library paths and check for the java_libglom .so.
-		for (final String libDirName : javaLibraryPath.split(":")) {
-			final File libDir = new File(libDirName);
-
-			if (!libDir.isDirectory())
-				continue;
-			if (!libDir.canRead())
-				continue;
-
-			final File[] libs = libDir.listFiles(new FilenameFilter() {
-				@Override
-				public boolean accept(final File dir, final String name) {
-					return name.matches("libjava_libglom-[0-9]\\.[0-9].+\\.so");
-				}
-			});
-
-			// if at least one directory had the .so, we're done
-			if (libs.length > 0)
-				return true;
-		}
-
-		return false;
-	}
-
 	/*
 	 * This is called when the servlet is stopped or restarted.
 	 * 
@@ -253,8 +197,6 @@ public class OnlineGlomServiceImpl extends RemoteServiceServlet implements Onlin
 	 */
 	@Override
 	public void destroy() {
-		Glom.libglom_deinit();
-
 		for (final String documenTitle : documentMapping.keySet()) {
 			final ConfiguredDocument configuredDoc = documentMapping.get(documenTitle);
 			if (configuredDoc == null)
@@ -291,11 +233,7 @@ public class OnlineGlomServiceImpl extends RemoteServiceServlet implements Onlin
 	@Override
 	public DocumentInfo getDocumentInfo(final String documentID, final String localeID) {
 
-		ConfiguredDocument configuredDoc = documentMapping.get(documentID);
-
-		// Avoid dereferencing a null object:
-		if (configuredDoc == null)
-			return new DocumentInfo();
+		final ConfiguredDocument configuredDoc = documentMapping.get(documentID);
 
 		// Avoid dereferencing a null object:
 		if (configuredDoc == null)
@@ -331,8 +269,8 @@ public class OnlineGlomServiceImpl extends RemoteServiceServlet implements Onlin
 	 * java.lang.String)
 	 */
 	@Override
-	public String getReportHTML(final String documentID, final String tableName, final String reportName, final String quickFind, 
-			final String localeID) {
+	public String getReportHTML(final String documentID, final String tableName, final String reportName,
+			final String quickFind, final String localeID) {
 		final ConfiguredDocument configuredDoc = documentMapping.get(documentID);
 		if (configuredDoc == null)
 			return "";
@@ -347,7 +285,7 @@ public class OnlineGlomServiceImpl extends RemoteServiceServlet implements Onlin
 
 		// FIXME check for authentication
 
-		final Report report = glomDocument.get_report(tableName, reportName);
+		final Report report = glomDocument.getReport(tableName, reportName);
 		if (report == null) {
 			Log.info(documentID, tableName, "The report layout is not defined for this table:" + reportName);
 			return "";
@@ -424,7 +362,7 @@ public class OnlineGlomServiceImpl extends RemoteServiceServlet implements Onlin
 			}
 
 			final String localeID = StringUtils.defaultString(configuredDoc.getDefaultLocaleID());
-			documents.addDocument(documentID, glomDocument.get_database_title(localeID), localeID);
+			documents.addDocument(documentID, glomDocument.getDatabaseTitle(localeID), localeID);
 		}
 		return documents;
 	}
@@ -484,9 +422,12 @@ public class OnlineGlomServiceImpl extends RemoteServiceServlet implements Onlin
 	@Override
 	public DataItem[] getDetailsData(final String documentID, final String tableName,
 			final TypedDataItem primaryKeyValue) {
+		//An empty tableName is OK, because that means the default table.
+
 		final ConfiguredDocument configuredDoc = documentMapping.get(documentID);
-		if (configuredDoc == null)
+		if (configuredDoc == null) {
 			return new DataItem[0];
+		}
 
 		// FIXME check for authentication
 
@@ -502,9 +443,12 @@ public class OnlineGlomServiceImpl extends RemoteServiceServlet implements Onlin
 	@Override
 	public DetailsLayoutAndData getDetailsLayoutAndData(final String documentID, final String tableName,
 			final TypedDataItem primaryKeyValue, final String localeID) {
+		//An empty tableName is OK, because that means the default table.
+
 		final ConfiguredDocument configuredDoc = documentMapping.get(documentID);
-		if (configuredDoc == null)
+		if (configuredDoc == null) {
 			return null;
+		}
 
 		// FIXME check for authentication
 
@@ -523,12 +467,19 @@ public class OnlineGlomServiceImpl extends RemoteServiceServlet implements Onlin
 	 */
 	@Override
 	public ArrayList<DataItem[]> getRelatedListData(final String documentID, final String tableName,
-			final String relationshipName, final TypedDataItem foreignKeyValue, final int start, final int length) {
+			final LayoutItemPortal portal, final TypedDataItem foreignKeyValue, final int start, final int length) {
+		//An empty tableName is OK, because that means the default table.
+		
+		if(portal == null) {
+			Log.error("getRelatedListData(): portal is null.");
+			return null;
+		}
+
 		final ConfiguredDocument configuredDoc = documentMapping.get(documentID);
 
 		// FIXME check for authentication
 
-		return configuredDoc.getRelatedListData(tableName, relationshipName, foreignKeyValue, start, length, false, 0,
+		return configuredDoc.getRelatedListData(tableName, portal, foreignKeyValue, start, length, false, 0,
 				false);
 	}
 
@@ -540,28 +491,43 @@ public class OnlineGlomServiceImpl extends RemoteServiceServlet implements Onlin
 	 */
 	@Override
 	public ArrayList<DataItem[]> getSortedRelatedListData(final String documentID, final String tableName,
-			final String relationshipName, final TypedDataItem foreignKeyValue, final int start, final int length,
+			final LayoutItemPortal portal, final TypedDataItem foreignKeyValue, final int start, final int length,
 			final int sortColumnIndex, final boolean ascending) {
+		//An empty tableName is OK, because that means the default table.
+		
+		if(portal == null) {
+			Log.error("getSortedRelatedListData(): portal is null.");
+			return null;
+		}
+
 		final ConfiguredDocument configuredDoc = documentMapping.get(documentID);
 		if (configuredDoc == null)
 			return new ArrayList<DataItem[]>();
 
 		// FIXME check for authentication
 
-		return configuredDoc.getRelatedListData(tableName, relationshipName, foreignKeyValue, start, length, true,
+		return configuredDoc.getRelatedListData(tableName, portal, foreignKeyValue, start, length, true,
 				sortColumnIndex, ascending);
 	}
 
 	@Override
-	public int getRelatedListRowCount(final String documentID, final String tableName, final String relationshipName,
+	public int getRelatedListRowCount(final String documentID, final String tableName, final LayoutItemPortal portal,
 			final TypedDataItem foreignKeyValue) {
-		final ConfiguredDocument configuredDoc = documentMapping.get(documentID);
-		if (configuredDoc == null)
+		//An empty tableName is OK, because that means the default table.
+		
+		if(portal == null) {
+			Log.error("getRelatedListRowCount(): portal is null");
 			return 0;
+		}
+
+		final ConfiguredDocument configuredDoc = documentMapping.get(documentID);
+		if (configuredDoc == null) {
+			return 0;
+		}
 
 		// FIXME check for authentication
 
-		return configuredDoc.getRelatedListRowCount(tableName, relationshipName, foreignKeyValue);
+		return configuredDoc.getRelatedListRowCount(tableName, portal, foreignKeyValue);
 	}
 
 	/*
@@ -572,14 +538,22 @@ public class OnlineGlomServiceImpl extends RemoteServiceServlet implements Onlin
 	 */
 	@Override
 	public NavigationRecord getSuitableRecordToViewDetails(final String documentID, final String tableName,
-			final String relationshipName, final TypedDataItem primaryKeyValue) {
+			final LayoutItemPortal portal, final TypedDataItem primaryKeyValue) {
+		//An empty tableName is OK, because that means the default table.
+		
+		if(portal == null) {
+			Log.error("getSuitableRecordToViewDetails(): portal is null");
+			return null;
+		}
+		
 		final ConfiguredDocument configuredDoc = documentMapping.get(documentID);
-		if (configuredDoc == null)
-			return new NavigationRecord();
+		if (configuredDoc == null) {
+			return null;
+		}
 
 		// FIXME check for authentication
 
-		return configuredDoc.getSuitableRecordToViewDetails(tableName, relationshipName, primaryKeyValue);
+		return configuredDoc.getSuitableRecordToViewDetails(tableName, portal, primaryKeyValue);
 	}
 
 }
